@@ -30,3 +30,6 @@ pub use shared::metadata::{Meta, Metadata};
 pub use shared::recurrence::{RRuleFrequency, RRuleOptions};
 pub use timespan::TimeSpan;
 pub use user::{IntegrationProvider, User, UserIntegration};
+
+pub use chrono::Weekday;
+pub use chrono_tz::Tz;
